@@ -41,7 +41,9 @@ type stat =
     (** Total size of the major heap, in words. *)
 
     heap_chunks : int;
-    (** Number of contiguous pieces of memory that make up the major heap. *)
+    (** Number of contiguous pieces of memory that make up the major heap.
+        This metrics is currently not available in OCaml 5: the field value is
+        always [0]. *)
 
     live_words : int;
     (** Number of words of live data in the major heap, including the header
@@ -68,10 +70,14 @@ type stat =
     (** Number of words in the free list. *)
 
     free_blocks : int;
-    (** Number of blocks in the free list. *)
+    (** Number of blocks in the free list.
+        This metrics is currently not available in OCaml 5: the field value is
+        always [0]. *)
 
     largest_free : int;
-    (** Size (in words) of the largest block in the free list. *)
+    (** Size (in words) of the largest block in the free list.
+        This metrics is currently not available in OCaml 5: the field value
+        is always [0]. *)
 
     fragments : int;
     (** Number of wasted words due to fragmentation.  These are
@@ -86,12 +92,14 @@ type stat =
 
     stack_size: int;
     (** Current size of the stack, in words.
-        @since 3.12.0 *)
+        This metrics is currently not available in OCaml 5: the field value is
+        always [0].
+        @since 3.12 *)
 
     forced_major_collections: int;
     (** Number of forced full major collections completed since the program
         was started.
-        @since 4.12.0 *)
+        @since 4.12 *)
 }
 (** The memory management counters are returned in a [stat] record. These
    counters give values for the whole program.
@@ -191,14 +199,14 @@ type control =
 
         Default: 2.
 
-        @since 3.11.0 *)
+        @since 3.11 *)
 
     window_size : int;
     (** The size of the window used by the major GC for smoothing
         out variations in its workload. This is an integer between
         1 and 50.
         Default: 1.
-        @since 4.03.0 *)
+        @since 4.03 *)
 
     custom_major_ratio : int;
     (** Target ratio of floating garbage to major heap size for
@@ -211,7 +219,7 @@ type control =
         Note: this only applies to values allocated with
         [caml_alloc_custom_mem] (e.g. bigarrays).
         Default: 44.
-        @since 4.08.0 *)
+        @since 4.08 *)
 
     custom_minor_ratio : int;
     (** Bound on floating garbage for out-of-heap memory held by
@@ -221,7 +229,7 @@ type control =
         Note: this only applies to values allocated with
         [caml_alloc_custom_mem] (e.g. bigarrays).
         Default: 100.
-        @since 4.08.0 *)
+        @since 4.08 *)
 
     custom_minor_max_size : int;
     (** Maximum amount of out-of-heap memory for each custom value
@@ -232,7 +240,7 @@ type control =
         Note: this only applies to values allocated with
         [caml_alloc_custom_mem] (e.g. bigarrays).
         Default: 8192 bytes.
-        @since 4.08.0 *)
+        @since 4.08 *)
   }
 (** The GC parameters are given as a [control] record.  Note that
     these parameters can also be initialised by setting the
@@ -316,7 +324,7 @@ external get_minor_free : unit -> int = "caml_get_minor_free"
 (** Return the current size of the free space inside the minor heap of this
    domain.
 
-    @since 4.03.0 *)
+    @since 4.03 *)
 
 val finalise : ('a -> unit) -> 'a -> unit
 (** [finalise f v] registers [f] as a finalisation function for [v].
@@ -411,7 +419,8 @@ type alarm
 
 val create_alarm : (unit -> unit) -> alarm
 (** [create_alarm f] will arrange for [f] to be called at the end of each
-   major GC cycle, starting with the current cycle or the next one.
+   major GC cycle, not caused by [f] itself, starting with the current
+   cycle or the next one.
    A value of type [alarm] is returned that you can
    use to call [delete_alarm]. *)
 
